@@ -8,6 +8,7 @@ import numpy as np
 import scipy.sparse as sparse
 import scipy.stats
 import pandas.api.types as pat
+from sklearn.preprocessing import StandardScaler
 import scipy.io
 from anndata import AnnData
 from inferelator.utils import Debug, Validator
@@ -232,6 +233,10 @@ class InferelatorData(object):
     def expression_data(self):
         return self._adata.X
 
+    @expression_data.setter
+    def expression_data(self, new_data):
+        self._adata.X = new_data
+
     @property
     def values(self):
         return self._adata.X
@@ -330,6 +335,17 @@ class InferelatorData(object):
     def gene_counts(self):
         return self._adata.X.sum(axis=0).A.flatten() if self.is_sparse else self._adata.X.sum(axis=0)
 
+    @property
+    def gene_means(self):
+        return self._adata.X.mean(axis=0).A.flatten() if self.is_sparse else self._adata.X.mean(axis=0)
+
+    @property
+    def gene_stdev(self):
+        if self.is_sparse:
+            return np.sqrt(StandardScaler(copy=False, with_mean=False).fit(self._adata.X).var_)
+        else:
+            return self._adata.X.std(axis=0, ddof=1)
+
     @property
     def sample_names(self):
         return self._adata.obs_names
@@ -344,7 +360,10 @@ class InferelatorData(object):
 
     @property
     def sample_stdev(self):
-        return self._adata.X.std(axis=1, ddof=1).A.flatten() if self.is_sparse else self._adata.X.std(axis=1, ddof=1)
+        if self.is_sparse:
+            return np.sqrt(StandardScaler(copy=False, with_mean=False).fit(self._adata.X.T).var_)
+        else:
+            return self._adata.X.std(axis=1, ddof=1)
 
     @property
     def non_finite(self):
@@ -374,8 +393,9 @@ class InferelatorData(object):
     def num_genes(self):
         return self._adata.shape[1]
 
-    def __getattr__(self, item):
-        return getattr(self._adata, item)
+    @property
+    def uns(self):
+        return self._adata.uns
 
     def __str__(self):
         msg = "InferelatorData [{dt} {sh}, Metadata {me}] Memory: {mem:.2f} MB"
@@ -506,8 +526,13 @@ class InferelatorData(object):
         comp = 0 if self._is_integer else np.finfo(self.values.dtype).eps * 10
 
         if remove_constant_genes:
-            nz_var = (self.values.max(axis=0) - self.values.min(axis=0))
-            nz_var = comp < (nz_var.A.flatten() if self.is_sparse else nz_var)
+            nz_var = self.values.max(axis=0) - self.values.min(axis=0)
+            nz_var = nz_var.A.flatten() if self.is_sparse else nz_var
+
+            if np.any(np.isnan(nz_var)):
+                raise ValueError("NaN values are present in the expression matrix; unable to remove var=0 genes")
+
+            nz_var = comp < nz_var
 
             keep_column_bool &= nz_var
             var_zero_trim = np.sum(nz_var)
@@ -760,6 +785,9 @@ class InferelatorData(object):
         elif not self.is_sparse:
             raise ValueError("Mode must be csc or csr")
 
+    def to_df(self):
+        return self._adata.to_df()
+
     @staticmethod
     def _make_idx_str(df):
         df.index = df.index.astype(str) if not pat.is_string_dtype(df.index.dtype) else df.index
